# ZhousfLib

python常用工具库：coco数据集、labelme数据集、segmentation数据集、classification数据集制作和转换脚本

### 数据集制作

* [x] datasets/classification
* [x] datasets/coco
* [x] datasets/labelme
* [x] datasets/segmentation

### 数据库

* [x] db/lmdb

### 装饰器

* [x] decorator(异常捕获，AOP)

### 字体

* [x] font(宋体、特殊符号)

### 并发压测工具

* [x] locust（demo）

### 表格文件工具

* [x] pandas（excel、csv、大文件读取）

### pdf文件工具

* [x] pdf（pdf导出图片、pdf文本和表格提取）

### web相关

* [x] web（flask日志工具、响应体、配置）

### 通用工具包

* [x] util

* [util/cv_util]：opencv读写中文路径图片
* [util/encrypt_util]：AES加密
* [util/iou_util]：IoU计算
* [util/json_util]：json读写
* [util/poly_util]：按照宽高对图片进行网格划分/切图
* [util/re_util]：re提取数字、字母、中文
* [util/singleton]：单例
* [util/string_util]：非空、包含、补齐
* [util/time_util]：日期、毫秒级时间戳、微秒级时间戳、日期比较

